#############################################################
# SELENIUM TOXICITY - Dose-Response Relationship
#
# Source: Jeske et. al. (2016). Testing for the equality of 
#         EC50 values in the presence of unequal slopes with
#         application to toxicity of selenium types.
#         JABES 14(4): 469-483
#############################################################

rm(list=ls()) 
setwd("C:/Users/Owner/Desktop/Online_Training/MEDICAL/Datasets/DOSE")
library(asreml)

# Reading dataset
TOXIC <- read.table("SELENIUM.TXT",header=TRUE)
head(TOXIC)

# Defining Factors
TOXIC$TYPE <- as.factor(TOXIC$TYPE)
TOXIC$PROP <- TOXIC$ND/TOXIC$NS

# EDA: Exploratory Data Analysis
hist(TOXIC$PROP)
table(TOXIC$TYPE,TOXIC$CONC)
library(ggplot2)
conc <- ggplot(data=TOXIC, aes(x=CONC, y=PROP)) + geom_line(aes(colour=TYPE))
conc + geom_hline(yintercept=0.5)
abline(h=0.5)

# Base-Model for Disease/Emergence - logit
? asr_families
m.logit <- asreml(fixed=ND~-1+TYPE+TYPE:CONC,
               family=asr_binomial(link='logit',dispersion=1,total=NS),
               data=TOXIC)
plot(m.logit)
summary(m.logit)$varcomp
wald.asreml(m.logit,denDF='numeric',ssType='incremental')
summary(m.logit,coef=TRUE)$coef.fixed

# Base-Model for Disease/Emergence - logit - overdispersed model
? asr_families
m.logit <- asreml(fixed=ND~-1+TYPE+TYPE:CONC,
                  family=asr_binomial(link='logit',dispersion=7.87,total=NS),
                  data=TOXIC)
plot(m.logit)
wald.asreml(m.logit,denDF='numeric',ssType='incremental')
summary(m.logit,coef=TRUE)$coef.fixed

# Obtaining Predictions - overdispersed model
predict(m.baseF,classify='TYPE:CONC')
predict(m.baseF,classify='TYPE:CONC',levels=list(CONC=c(0,50,100,200,300),TYPE=1))

# Finding EC50
predict(m.baseF,classify='TYPE:CONC',levels=list(CONC=300.2,TYPE=1))$pvals
predict(m.baseF,classify='TYPE:CONC',levels=list(CONC=395.5,TYPE=2))$pvals
predict(m.baseF,classify='TYPE:CONC',levels=list(CONC=155.5,TYPE=3))$pvals
predict(m.baseF,classify='TYPE:CONC',levels=list(CONC=85.2,TYPE=4))$pvals

#TYPE  CONC predicted.value std.error    status transformed.value  approx.se
#1   T1 300.2   -7.301939e-05 0.0822838 Estimable         0.4999817 0.02055932
#1   T2 395.5    0.0002959439 0.0893438 Estimable         0.5000740 0.02232126
#1   T3 155.5    0.0009014703 0.1175154 Estimable         0.5002254 0.02934586
#1   T4 85.2     0.0012637830 0.1422022 Estimable         0.5003159 0.03549233
